@@ -18,26 +18,33 @@ ArticlesEntry = get_class('cms.blocks.entries', 'ArticlesEntry')
 ButtonsEntry = get_class('cms.blocks.entries', 'ButtonsEntry')
 CardsEntry = get_class('cms.blocks.entries', 'CardsEntry')
 EmbedEntry = get_class('cms.blocks.entries', 'EmbedEntry')
-FirstContentEntry = get_class('cms.blocks.entries', 'FirstContentEntry')
 GridInfoEntry = get_class('cms.blocks.entries', 'GridInfoEntry')
 ImageEntry = get_class('cms.blocks.entries', 'ImageEntry')
-MediaTextEntry = get_class('cms.blocks.entries', 'MediaTextEntry')
+ComponentTextEntry = get_class('cms.blocks.entries', 'ComponentTextEntry')
 MediasLineEntry = get_class('cms.blocks.entries', 'MediasLineEntry')
 SvgEntry = get_class('cms.blocks.entries', 'SvgEntry')
 TextEntry = get_class('cms.blocks.entries', 'TextEntry')
 TimeLineEntry = get_class('cms.blocks.entries', 'TimeLineEntry')
 CalendlyEntry = get_class('cms.blocks.entries', 'CalendlyEntry')
+TableEntry = get_class('cms.blocks.entries', 'TableEntry')
+AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
+NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
+FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 
 # Models
 MenuItem = get_model('cms', 'MenuItem')
 Menu = get_model('cms', 'Menu')
 IconSnippet = get_model('cms', 'IconSnippet')
+Navigation = get_model('cms', 'Navigation')
+
 HomePage = get_model('cms', 'HomePage')
 ContentPage = get_model('cms', 'ContentPage')
 BlogPage = get_model('cms', 'BlogPage')
 BlogIndexPage = get_model('cms', 'BlogIndexPage')
 WebspaceSettings = get_model('cms', 'WebspaceSettings')
 MyDocument = get_model('cms', 'MyDocument')
+Form = get_model('cms', 'Form')
+FormField = get_model('cms', 'FormField')
 
 
 class Command(BaseCommand):
@@ -58,20 +65,26 @@ class Command(BaseCommand):
         #  MyDocument.objects.all().delete()
         Menu.objects.all().delete()
         MenuItem.objects.all().delete()
+        Navigation.objects.all().delete()
+        Form.objects.all().delete()
+        FormField.objects.all().delete()
 
         article_entry = ArticlesEntry()
         buttons_entry = ButtonsEntry()
         cards_entry = CardsEntry()
         embed_entry = EmbedEntry()
-        first_content_entry = FirstContentEntry()
         grid_info_entry = GridInfoEntry()
         image_entry = ImageEntry()
-        media_text_entry = MediaTextEntry()
+        component_text_entry = ComponentTextEntry()
         medias_line_entry = MediasLineEntry()
         svg_entry = SvgEntry()
         text_entry = TextEntry()
         time_line_entry = TimeLineEntry()
         calendly_entry = CalendlyEntry()
+        table_entry = TableEntry()
+        accordion_entry = AccordionEntry()
+        numbers_entry = NumbersEntry()
+        form_entry = FormEntry()
 
         mocker = Mocker()
 
@@ -104,14 +117,14 @@ class Command(BaseCommand):
             depth=2,
             numchild=0,
             body=json.dumps([
-                first_content_entry.mock(bg=True),
+                component_text_entry.mock(bg=True),
                 cards_entry.mock(stop=3, carousel=False, container='regular', theme=constants.THEME_LIGHT),
-                media_text_entry.mock(size_media='l', reverse=True, section=True),
+                component_text_entry.mock(size_component='l', reverse=True, section=True),
                 cards_entry.mock(container='full'),
-                media_text_entry.mock(size_media='l', theme=constants.THEME_LIGHT, section=True),
+                component_text_entry.mock(size_component='l', theme=constants.THEME_LIGHT, section=True),
                 cards_entry.mock(container='full', theme=constants.THEME_LIGHT),
-                media_text_entry.mock(size_media='l', reverse=True),
-                media_text_entry.mock(theme=constants.THEME_LIGHT),
+                component_text_entry.mock(size_component='l', reverse=True),
+                component_text_entry.mock(theme=constants.THEME_LIGHT),
             ])
         )
         home_page.save()
@@ -134,13 +147,13 @@ class Command(BaseCommand):
             title="Content Page",
             slug='content',
             body=json.dumps([
-                first_content_entry.mock(),
-                media_text_entry.mock(theme=constants.THEME_LIGHT),
+                component_text_entry.mock(),
+                component_text_entry.mock(theme=constants.THEME_LIGHT),
                 time_line_entry.mock(theme=constants.THEME_LIGHT),
                 text_entry.mock(txt='<h2>Loreum</h2>', align='center', theme=constants.THEME_SPACE),
-                media_text_entry.mock(reverse=True, theme=constants.THEME_SPACE),
-                media_text_entry.mock(theme=constants.THEME_SPACE_INVERSE),
-                media_text_entry.mock(theme=constants.THEME_LIGHT),
+                component_text_entry.mock(reverse=True, theme=constants.THEME_SPACE),
+                component_text_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                component_text_entry.mock(theme=constants.THEME_LIGHT),
             ])
         )
         home_page.add_child(instance=content_page)
@@ -263,57 +276,60 @@ class Command(BaseCommand):
         mocker.menu(carousel_page, block_menu_id)
         mocker.add_menu(carousel_page, home_page_menu_id)
 
-        # -------------------------------- Media Text --------------------------------
+        # -------------------------------- Component Text --------------------------------
 
         media_text_page = ContentPage(
-            title="Media Text",
-            slug='media-text',
+            title="Component Text",
+            slug='component-text',
             body=json.dumps([
-                text_entry.mock(txt='<h2>Media Text Regular</h2>', align='center'),
-                media_text_entry.mock(reverse=True),
-                media_text_entry.mock(theme=constants.THEME_LIGHT),
+                text_entry.mock(txt='<h2>Component Text Regular</h2>', align='center'),
+                component_text_entry.mock(reverse=True),
+                component_text_entry.mock(theme=constants.THEME_LIGHT),
 
-                text_entry.mock(txt='<h2>Media Text Embed</h2>', align='center'),
-                media_text_entry.mock(media='embed', size_media='xl'),
+                text_entry.mock(txt='<h2>Component Text Embed</h2>', align='center'),
+                component_text_entry.mock(component='embed', size_component='xl'),
 
-                text_entry.mock(txt='<h2>Media Text Size XL</h2>', align='center'),
-                media_text_entry.mock(size_media='xl', reverse=True),
-                media_text_entry.mock(size_media='xl', theme=constants.THEME_LIGHT),
+                text_entry.mock(txt='<h2>Component Text Form</h2>', align='center'),
+                component_text_entry.mock(component='form'),
 
-                text_entry.mock(txt='<h2>Media Text Buttons</h2>', align='center'),
-                media_text_entry.mock(
+                text_entry.mock(txt='<h2>Component Text Size XL</h2>', align='center'),
+                component_text_entry.mock(size_component='xl', reverse=True),
+                component_text_entry.mock(size_component='xl', theme=constants.THEME_LIGHT),
+
+                text_entry.mock(txt='<h2>Component Text Buttons</h2>', align='center'),
+                component_text_entry.mock(
                     reverse=True,
                     button_1=constants.BUTTON_SECONDARY_FULL,
                     button_2=constants.BUTTON_SECONDARY
                 ),
-                media_text_entry.mock(
+                component_text_entry.mock(
                     theme=constants.THEME_LIGHT,
                     button_1=constants.BUTTON_PRIMARY_FULL,
                     button_2=constants.BUTTON_PRIMARY
                 ),
 
-                text_entry.mock(txt='<h2>Media Text Background</h2>', align='center'),
-                media_text_entry.mock(
+                text_entry.mock(txt='<h2>Component Text Background</h2>', align='center'),
+                component_text_entry.mock(
                     reverse=True,
                     button_1=constants.BUTTON_TERTIARY_FULL,
                     button_2=constants.BUTTON_TERTIARY,
                     bg=True
                 ),
-                media_text_entry.mock(
+                component_text_entry.mock(
                     theme=constants.THEME_LIGHT,
                     button_1=constants.BUTTON_SECONDARY_FULL,
                     button_2=constants.BUTTON_SECONDARY,
                     bg=True
                 ),
 
-                text_entry.mock(txt='<h2>Media Text Align</h2>', align='center'),
-                media_text_entry.mock(
+                text_entry.mock(txt='<h2>Component Text Align</h2>', align='center'),
+                component_text_entry.mock(
                     align='justify',
                     reverse=True,
                     button_1=constants.BUTTON_TERTIARY_FULL,
                     button_2=constants.BUTTON_TERTIARY,
                 ),
-                media_text_entry.mock(
+                component_text_entry.mock(
                     theme=constants.THEME_LIGHT,
                     button_1=constants.BUTTON_SECONDARY_FULL,
                     button_2=constants.BUTTON_SECONDARY,
@@ -383,38 +399,6 @@ class Command(BaseCommand):
         mocker.menu(image_page, block_menu_id)
         mocker.add_menu(image_page, home_page_menu_id)
 
-        # -------------------------------- First Content --------------------------------
-
-        first_content_page = ContentPage(
-            title="First Content",
-            slug='first-content',
-            body=json.dumps([
-                first_content_entry.mock(),
-                first_content_entry.mock(
-                    theme=constants.THEME_LIGHT,
-                    button_1=constants.BUTTON_SECONDARY,
-                    button_2=constants.BUTTON_SECONDARY_FULL
-                ),
-                first_content_entry.mock(align='center'),
-                first_content_entry.mock(
-                    align='center',
-                    theme=constants.THEME_LIGHT,
-                    button_1=constants.BUTTON_SECONDARY,
-                    button_2=constants.BUTTON_SECONDARY_FULL
-                ),
-                first_content_entry.mock(align='right'),
-                first_content_entry.mock(
-                    align='right',
-                    theme=constants.THEME_LIGHT,
-                    button_1=constants.BUTTON_SECONDARY,
-                    button_2=constants.BUTTON_SECONDARY_FULL
-                )
-            ])
-        )
-        block_page.add_child(instance=first_content_page)
-        mocker.menu(first_content_page, block_menu_id)
-        mocker.add_menu(first_content_page, home_page_menu_id)
-
         # -------------------------------- TimeLine --------------------------------
 
         timeline_page = ContentPage(
@@ -506,14 +490,82 @@ class Command(BaseCommand):
         mocker.menu(calendly_page, block_menu_id)
         mocker.add_menu(calendly_page, home_page_menu_id)
 
+        # -------------------------------- Table --------------------------------
+
+        table_page = ContentPage(
+            title="Table",
+            slug='table',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Tables</h1>', align='center'),
+                table_entry.mock(),
+                table_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                table_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=table_page)
+        mocker.menu(table_page, block_menu_id)
+        mocker.add_menu(table_page, home_page_menu_id)
+
+        # -------------------------------- Accordion --------------------------------
+
+        accordion_page = ContentPage(
+            title="Accordion",
+            slug='accordion',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Accordion</h1>', align='center'),
+                accordion_entry.mock(),
+                accordion_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                accordion_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=accordion_page)
+        mocker.menu(accordion_page, block_menu_id)
+        mocker.add_menu(accordion_page, home_page_menu_id)
+
+        # -------------------------------- Numbers --------------------------------
+
+        numbers_page = ContentPage(
+            title="Numbers",
+            slug='numbers',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Numbers</h1>', align='center'),
+                numbers_entry.mock(),
+                numbers_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                numbers_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=numbers_page)
+        mocker.menu(numbers_page, block_menu_id)
+        mocker.add_menu(numbers_page, home_page_menu_id)
+
+        # -------------------------------- Forms --------------------------------
+
+        forms_page = ContentPage(
+            title="Forms",
+            slug='forms',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Form</h1>', align='center'),
+                form_entry.mock(),
+                form_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                form_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=forms_page)
+        mocker.menu(forms_page, block_menu_id)
+        mocker.add_menu(forms_page, home_page_menu_id)
+
         # -------------------------------- Settings --------------------------------
 
         ws_settings = WebspaceSettings.for_site(site)
         ws_settings.brand_name = "SpaceX"
-        ws_settings.logo_header = json.dumps([{
+        ws_settings.logo_header_primary = json.dumps([{
             'type': 'svg',
             'value': mocker.file(mocker.SVG_LOGO_SPACE).id
         }])
+        ws_settings.logo_header_secondary = json.dumps([{
+            'type': 'svg',
+            'value': mocker.file(mocker.SVG_LOGO_LIGHT).id
+        }])
         ws_settings.favicon = mocker.file(mocker.IMG_ICON_SPACE)
         ws_settings.language = 'fr'
         ws_settings.collect_text = "<p>En poursuivant votre navigation sur ce site, vous acceptez nos CGU ainsi que notre Politique de confidentialité</p>"
@@ -523,10 +575,14 @@ class Command(BaseCommand):
         <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
             recrutent.</p>
         """
+        ws_settings.newsletter = Mocker.get_form('newsletter', nb_fields=1, head_text=False)
+
         ws_settings.facebook = mocker.URL_TEST
         ws_settings.instagram = mocker.URL_TEST
         ws_settings.linkedin = mocker.URL_TEST
         ws_settings.twitter = mocker.URL_TEST
+        ws_settings.youtube = mocker.URL_TEST
+        ws_settings.pinterest = mocker.URL_TEST
         ws_settings.save()
 
         rss = RSSFeedsSettings.for_site(site)
@@ -555,6 +611,8 @@ class Command(BaseCommand):
             "instagram",
             "linkedin",
             "twitter",
+            "youtube",
+            "pinterest",
             "info",
             "right",
             "left",
@@ -568,6 +626,8 @@ class Command(BaseCommand):
             "time",
             "user",
             "accordion",
+            "fr",
+            "en"
         ]
         for key in keys:
             ico, created = IconSnippet.objects.get_or_create(
