@@ -1,3 +1,5 @@
+import logging
+import re
 from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
 
@@ -5,6 +7,8 @@ from django import template
 
 register = template.Library()
 
+logger = logging.getLogger('forms')
+
 
 def ico(icon, theme):
     if theme == 'space':
@@ -48,17 +52,33 @@ def embed(url):
         ret = ret.replace('src=', 'class="lazy" data-src=')
         return ret
     except EmbedException:
-        # Cannot find embed
-        pass
+        return "<iframe class='lazy' data-src='%s'></iframe>" % url
 
 
 def strfix(value):
     return value.replace('\n', '')
 
 
+def klass(ob):
+    return re.sub('(((?<=[a-z])[A-Z])|([A-Z](?![A-Z]|$)))', '-\\1', ob.__class__.__name__).lower().strip('-')
+
+
+def cached_form(form, request):
+    if form:
+        if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session['current_form_id']:
+            logger.debug("Take form cached")
+            return form.get_form(request.POST, request.FILES, user=request.user)
+        logger.debug("Take new form")
+        return form.get_form()
+    logger.debug("No forms")
+    return []
+
+
 register.filter('ico', ico)
 register.filter('ico_astro', ico_astro)
 register.filter('ico_get', ico_get)
 register.filter('plur', plur)
 register.filter('embed', embed)
 register.filter('strfix', strfix)
+register.filter('klass', klass)
+register.filter('cached_form', cached_form)
